Class: OmniAuth::Strategies::MLH
- Inherits:
-
OAuth2
- Object
- OAuth2
- OmniAuth::Strategies::MLH
- Defined in:
- lib/omniauth/strategies/mlh.rb
Overview
MLH OAuth2 Strategy
When offline_access scope is requested, the strategy will include refresh_token in the credentials hash if provided by the server.
Instance Method Summary collapse
Instance Method Details
#data ⇒ Object
66 67 68 69 70 |
# File 'lib/omniauth/strategies/mlh.rb', line 66 def data @data ||= fetch_and_process_data.compact rescue StandardError {} end |